aboutsummaryrefslogtreecommitdiff
path: root/source/opt/feature_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/opt/feature_manager.h')
-rw-r--r--source/opt/feature_manager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/opt/feature_manager.h b/source/opt/feature_manager.h
index 4720c6dc..68c8e9a2 100644
--- a/source/opt/feature_manager.h
+++ b/source/opt/feature_manager.h
@@ -55,8 +55,8 @@ class FeatureManager {
return extinst_importid_OpenCL100DebugInfo_;
}
- uint32_t GetExtInstImportId_Vulkan100DebugInfo() const {
- return extinst_importid_Vulkan100DebugInfo_;
+ uint32_t GetExtInstImportId_Shader100DebugInfo() const {
+ return extinst_importid_Shader100DebugInfo_;
}
friend bool operator==(const FeatureManager& a, const FeatureManager& b);
@@ -97,9 +97,9 @@ class FeatureManager {
// for performance.
uint32_t extinst_importid_OpenCL100DebugInfo_ = 0;
// Common NonSemanticVulkan100DebugInfo external instruction import ids,
// cached for performance.
- uint32_t extinst_importid_Vulkan100DebugInfo_ = 0;
+ uint32_t extinst_importid_Shader100DebugInfo_ = 0;
};
} // namespace opt
@@ -97,9 +97,9 @@ class FeatureManager {
// for performance.
uint32_t extinst_importid_OpenCL100DebugInfo_ = 0;
- // Common NonSemanticVulkan100DebugInfo external instruction import ids,
+ // Common NonSemanticShader100DebugInfo external instruction import ids,
// cached for performance.